@@ -77,9 +77,9 @@ impl ChunkWalker {
 
     #[cfg(all(target_arch = "wasm32", feature = "tree-sitter"))]
     #[inline]
-    pub fn callback_adapter_for_tree_sitter(self) -> impl FnMut(u32, tree_sitter::Point) -> Bytes {
+    pub fn callback_adapter_for_tree_sitter(self) -> impl FnMut(u32, Option<tree_sitter::Point>, Option<u32>) -> Bytes {
         let mut adapter = self.callback_adapter();
-        move |start_index, _position| adapter(start_index, None)
+        move |start_index, _position, end_index| adapter(start_index, end_index)
     }
 }
 
